@@ -3,12 +3,12 @@ from embetter.error import NotInstalled
 try:
     from embetter.text._sbert import SentenceEncoder
 except ModuleNotFoundError:
-    SentenceEncoder = NotInstalled("SentenceEncoder", "sbert")
+    SentenceEncoder = NotInstalled("SentenceEncoder", "sentence-tfm")
 
 try:
     from embetter.text._s2v import Sense2VecEncoder
 except ModuleNotFoundError:
-    Sense2VecEncoder = NotInstalled("Sense2VecEncoder", "sbert")
+    Sense2VecEncoder = NotInstalled("Sense2VecEncoder", "sense2vec")
 
 
 __all__ = ["SentenceEncoder", "Sense2VecEncoder"]
